function status = nc_addrecs ( ncfile, new_data )
% NC_ADDRECS:  add records onto the end of a netcdf file
%
% USAGE:  status = nc_addrecs ( ncfile, new_data );
% 
% INPUT:
%   ncfile:  netcdf file
%   new_data:  Matlab structure.  Each field is a data array
%      to be written to the netcdf file.  Each array had
%      better be the same length.  All arrays are written
%      in the same fashion.
%     
% OUTPUT:
%   status:  -1 if the routine fails
%
% AUTHOR: 
%   johnevans@acm.org
%





%
% Open netCDF file
%
[cdfid,rcode ]=ncmex('open',ncfile,'NOWRITE');
if cdfid < 0
   disp(['Error in ncmex: Can''t open ' ncfile]);
   return
end

% Suppress warning messages from netCDF
[rcode]=ncmex('setopts',0);

%
% Get the dimension info for time
[dim_name,dim_size,rcode]=ncmex('diminq',cdfid,'time');
time_corner(1) = dim_size;
time_count(1) = size(new_data.time,1);


status = ncmex('close',cdfid);
if status == -1
	fprintf ( 2, '%s:  ncmex::close failed on %s.\n', mfilename, ncfile );
	return
end


%
% Assume failure until we know otherwise.
status = -1;

varnames = fieldnames ( new_data );


%
% write out each data field, as well as the minimum and maximum
for i = 1:length(varnames)

    var = varnames{i};

    data = getfield ( new_data, var );
	[r,c] = size(data);

	corner = [];
	count = [];
	corner(1) = time_corner(1);
	count(1) = time_count(1);
	if ( c > 1 )
		corner(2) = 0;
		count(2) = c;
	end



    status = ncvarput ( ncfile, var, data, corner, count );
    if ( status == -1 )
        fprintf ( 2, '%s:  ncvarput failed on %s:%s\n', mfilename, ncfile, varnames{i} );
        return
    end
   

end


%
% If here, we know we did ok
status = 1;

return





