function [values, status, msg] = nc_attget(cdf, var, att)
% NC_ATTGET: Get the values of a NetCDF attribute.
%
% USAGE:  [values, status, msg] = nc_attget(ncfile, var, att);
%
% PARAMETERS:
% Input:
%   cdf:  name of netcdf file in question
%   var:  name of variable in question, use '' or 'GLOBAL'
%         to retrieve on a global file attribute.
%   att:  name of attribute in question
% Output:    
%   values:  return value of attribute asked for
%   status:  optional, -1 for failure, 0 for success
%   msg:  
%      optional, displays any error message.  If supplied, then
%      this routine runs silently.
%      
%
% Example:
%    [values, status] = nc_attget('foo.cdf', 'x', 'scale_factor')



if nargout == 3 
	display_error_messages = 0;
else
	display_error_messages = 1;
end


%
% assume failure until we know otherwise.
status = -1;
values = [];
msg = '';

if nargin < 3
   help nc_attget
   return
end

%
% Suppress text messages.
[rcode]=ncmex('setopts',0);

cdfid=mexcdf('open',cdf,'nowrite');
if ( cdfid == -1 )
	msg = sprintf ( '%s:  Could not open %s.\n', mfilename, cdf );
	if ( display_error_messages )
		disp ( msg );
	end
	return
end


[dt, len, status]=mexcdf('attinq',cdfid,var,att);
if ( status == -1 )
	msg = sprintf ( '%s:  ''attinq'' failed on %s, %s, %s.\n', ...
	          mfilename, cdf, var, att );
	if ( display_error_messages )
		disp ( msg );
	end
	mexcdf('close',cdfid);
	return
end

[values, status]=mexcdf('attget',cdfid,var,att);
if ( status == -1 )
	msg = sprintf ( '%s:  ''attget'' failed on %s, %s, %s.\n', ...
	          mfilename, cdf, var, att );
	if ( display_error_messages )
		disp ( msg );
	end
	mexcdf('close',cdfid);
	return
end

mexcdf('close',cdfid);
