function [buffer, status] = nc_getfile_last(ncfile, num_datums)
% NC_GETLAST:  Get last few datums from a time series NetCDF variable for all time series variables.
%
% USAGE: [values, status] = nc_get_file_last( netcdf_file, variable, n )
%
% PARAMETERS:
%    values:  return data
%    status:  -1 if function failed, 0 if ok
%    netcdf_file:  name of netcdf file
%    variable:  name of variable to retrieve
%    n:  number of items to get, starting at the end
%
% Very similar to ncvarget except that we count back from
% the end.
%
% AUTHOR:  johnevans@acm.org
%






%
% assume failure until success is known
buffer = [];
status = -1;


% Show usage if too few arguments.
%
if nargin~=2 
   help nc_get_file_last;
   return;
end

nc_metadata = nc_getinfo ( ncfile );
if isempty( nc_metadata )
	fprintf ( '%s:  nc_getinfo failed on file %s.\n', mfilename, ncfile );
	return;
end


%
% Loop thru each one.  If it is a time series (or more generally, "unlimited dimension") variable,
% we will grab it's data
fnames = fieldnames ( nc_metadata.variables );

num_fields = length(fnames);
for j = 1:num_fields
	
	theVarName = fnames{j};

	if ( ~nc_istsvar ( ncfile, theVarName ) )
		continue;
	end

	nc_var_metadata = getfield ( nc_metadata.variables, theVarName );

	data_size = nc_var_metadata.data_size;


	data_start = zeros(size(data_size));
	data_start(1) = data_size(1) - num_datums;

	data_count = data_size;
	data_count(1) = num_datums;



	[values, status] = nc_varget ( ncfile, theVarName, data_start, data_count );
	if ( status == -1 )
		fprintf ( '%s:  nc_varget failed on variable %s, file %s.\n', mfilename, var, ncfile );
		return;
	end

	buffer = setfield ( buffer, theVarName, values );

end



return;




