function [theBuffer, status] = nc_getbuffer ( ncfile )
% NC_GETBUFFER:  read the entire contents of a netcdf file into a structure suitable for nc_add_recs
%
% USAGE:  struct = nc_getbuffer ( ncfile );
%
% PARAMETERS:
% ncfile:  
%    Input netcdf file name.
% struct:
%    Output.  Structure with all netcdf data present.  Each variable will
%    be a substructure.  Within each variable lies the data and each 
%    attribute.  The global attributes are stored in a sub-structure
%    called 'global_atts'
%







%
% assume failure until success is known
status = -1;
theBuffer = [];


% Show usage if too few arguments.
%
if nargin~=1 
   help nc_getall;
   return;
end


%
% Open netCDF file
%
[cdfid,rcode ]=ncmex('open',ncfile,'NOWRITE');
if cdfid < 0
	fprintf ( 2, '%s:  ncmex:open failed on %s.\n', mfilename, ncfile );
	return
end

% Suppress warning messages from netCDF
[rcode]=ncmex('setopts',0);


[time_dimid, rcode] = ncmex('DIMID', cdfid, 'time');
if rcode < 0
	fprintf ( 2, '%s:  ncmex:dimid failed on time.\n', mfilename );
	ncmex('close',cdfid);
    return
end



[ndims, nvars, ngatts, recdim, status] = ncmex('INQUIRE', cdfid);
if status < 0
	fprintf ( 2, '%s:  ncmex:inquire failed on %s.\n', mfilename, ncfile );
	ncmex('close',cdfid);
    return
end

for varid=0:nvars-1

	[varname, datatype, ndims, dims, natts, status] = ncmex('VARINQ', cdfid, varid);
	if status < 0 
		fprintf ( 2, '%s:  ncmex:varinq failed on varid %d, file %s.\n', mfilename, varid, ncfile );
		ncmex('close',cdfid);
	end

	if ( dims(1) ~= time_dimid )
		continue;
	end

	[values, status] = ncvarget(ncfile, varname);
	if status < 0 
		fprintf ( 2, '%s:  ncvarget failed on %s, file %s.\n', mfilename, varname, ncfile );
		ncmex('close',cdfid);
	end

	theBuffer = setfield ( theBuffer, varname, values );
%	command = sprintf ( 'data.%s.data = values;', varname );
%	eval (command );




end



ncmex('close',cdfid);

status = 1;

return
