function [values, status] = nc_getlast(ncfile, var, num_datums)
% NC_GETLAST:  Get last few datums from a time series NetCDF variable.
%
% USAGE: [values, status] = nc_getlast( netcdf_file, variable, n )
%
% PARAMETERS:
%    values:  return data
%    status:  -1 if function failed, 0 if ok
%    netcdf_file:  name of netcdf file
%    variable:  name of variable to retrieve
%    n:  number of items to get, starting at the end
%
% Very similar to ncvarget except that we count back from
% the end.
%
% AUTHOR:  johnevans@acm.org
%






%
% assume failure until success is known
values = [];
status = -1;


% Show usage if too few arguments.
%
if nargin~=3 
   help nc_getlast;
   return;
end

nc_var_metadata = nc_getvarinfo ( ncfile, var );

data_size = nc_var_metadata.data_size;


data_start = zeros(size(data_size));
data_start(1) = data_size(1) - num_datums;

data_count = data_size;
data_count(1) = num_datums;



[values, status] = nc_varget ( ncfile, var, data_start, data_count );


return;



