function varnames = nc_getvarnames ( ncfile )
% NC_GETVARNAMES:  Get the list of variables in a netcdf file
%
% USAGE:  vars = nc_getvarnames ( ncfile );
%
% PARAMETERS:
% ncfile:  
%    Input netcdf file name.
% varnames:
%    Output.  structure with each field being the name of a netcdf variable







%
% assume failure until success is known
status = -1;
varnames = [];


% Show usage if too few arguments.
%
if nargin~=1 
   help get_ncfile;
   return;
end


%
% Open netCDF file
%
[cdfid,rcode ]=ncmex('open',ncfile,'NOWRITE');
if cdfid < 0
	fprintf ( 2, '%s:  ncmex:open failed on %s.\n', mfilename, ncfile );
	return
end

% Suppress warning messages from netCDF
[rcode]=ncmex('setopts',0);


[ndims, nvars, ngatts, recdim, status] = ncmex('INQUIRE', cdfid);
if status < 0
	fprintf ( 2, '%s:  ncmex:inquire failed on %s.\n', mfilename, ncfile );
	ncmex('close',cdfid);
    return
end

for varid=0:nvars-1

	[varname, datatype, ndims, dims, natts, status] = ncmex('VARINQ', cdfid, varid);
	if status < 0 
		fprintf ( 2, '%s:  ncmex:varinq failed on varid %d, file %s.\n', mfilename, varid, ncfile );
		ncmex('close',cdfid);
	end

	varnames = setfield ( varnames, varname, [] );


end




ncmex('close',cdfid);

