function status = nc_iscoordvar ( ncfile, varname )
% NC_ISCOORDVAR:  yes if the given variable is also a coordinate variable.
%
% USAGE:  bool = nc_iscoordvar ( ncfile, varname );
%
% PARAMETERS:
% ncfile:  
%    Input netcdf file name.
% varname:  
%    variable to check




% assume false until we know otherwise
status = 0;




% Show usage if too few arguments.
%
if nargin~=2 
   help nc_iscoordvar;
   return;
end


%
% Open netCDF file
%
[cdfid,rcode ]=ncmex('open',ncfile,'NOWRITE');
if cdfid < 0
	fprintf ( 2, '%s:  ncmex:open failed on %s.\n', mfilename, ncfile );
	return
end

% Suppress warning messages from netCDF
[rcode]=ncmex('setopts',0);

[varid, rcode] = ncmex('VARID', cdfid, varname);
if rcode < 0
	fprintf ( 2, '%s:  ncmex:varid failed on %s, %s.\n', mfilename, varname, ncfile );
	ncmex('close',cdfid);
    return
end


[varname, datatype, ndims, dims, natts, status] = ncmex('VARINQ', cdfid, varname);
if status < 0 
	fprintf ( 2, '%s:  ncmex:varinq failed on varid %d, file %s.\n', mfilename, varid, ncfile );
	ncmex('close',cdfid);
end

if ndims > 1
	ncmex('close',cdfid);
	status = 0;
	return;
end


%
% If we are here, then we have a 1D variable.  Need to check the name of 
% its dimension
[dimname, length, status] = ncmex('DIMINQ', cdfid, dims(1));
if status < 0 
	fprintf ( 2, '%s:  ncmex:diminq failed on dimid %d, file %s.\n', mfilename, dims(1), ncfile );
	ncmex('close',cdfid);
	status = 0;
	return
end
ncmex('close',cdfid);

if ( strcmp(dimname,varname) )
	status = 1;
	return;
end


status = 0;
return;


