function status = nc_istsvar ( ncfile, varname )
% NC_ISCOORDVAR:  yes if the given variable is a time series variable
%
% USAGE:  bool = nc_iscoordvar ( ncfile, varname );
%
% Yes, if the first dimension of the named variable has the name of 'time'.
%
% PARAMETERS:
% ncfile:  
%    Input netcdf file name.
% varname:  
%    variable to check




% assume false until we know otherwise
status = 0;




% Show usage if too few arguments.
%
if nargin~=2 
   help nc_iscoordvar;
   return;
end


%
% Open netCDF file
%
[cdfid,rcode ]=ncmex('open',ncfile,'NOWRITE');
if cdfid < 0
	fprintf ( 2, '%s:  ncmex:open failed on %s.\n', mfilename, ncfile );
	return
end

% Suppress warning messages from netCDF
[rcode]=ncmex('setopts',0);

[varid, rcode] = ncmex('VARID', cdfid, varname);
if rcode < 0
	fprintf ( 2, '%s:  ncmex:varid failed on %s, %s.\n', mfilename, varname, ncfile );
	ncmex('close',cdfid);
    return
end


[varname, datatype, ndims, dims, natts, status] = ncmex('VARINQ', cdfid, varname);
if status < 0 
	fprintf ( 2, '%s:  ncmex:varinq failed on varid %d, file %s.\n', mfilename, varid, ncfile );
	ncmex('close',cdfid);
end


%
% try the first dimension
theDimid = dims(1);
[dim_name, length, status] = ncmex('diminq', cdfid, theDimid);
if status < 0 
	fprintf ( 2, '%s:  ncmex:diminq failed on varid %d, file %s.\n', mfilename, varid, ncfile );
	ncmex('close',cdfid);
end

ncmex('close',cdfid);

if ( strcmp(dim_name,'time') )
	status = 1;
	return;
end


status = 0;
return;


