function [varsize, status] = nc_varsize(cdf, var)
% NC_VARSIZE:  return the size of the requested netcdf variable
%
% USAGE: [varsize, status] = nc_varsize( netcdf_file, variable )
%
% PARAMETERS:
%   Input:
%      cdf:  path to netcdf file
%      var:  name of requested variable
%   Output:
%      varsize: size of requested variable 
%      status:  -1 if function failed, 0 if ok
%
% AUTHOR:  johnevans@acm.org
%






%
% assume failure until success is known
varsize = [];
status = -1;


% Show usage if too few arguments.
%
if nargin~=2 
   help nc_varsize;
   return;
end


%
% Open netCDF file
%
[cdfid,rcode ]=ncmex('open',cdf,'NOWRITE');
if cdfid < 0
	fprintf ( 2, '%s:  ncmex::open failed on %s.\n', mfilename, cdf );
    return
end

% Suppress warning messages from netCDF
[rcode]=ncmex('setopts',0);

%
% Get variable id
%
[varid]=ncmex('varid',cdfid,var);
if varid < 0
	fprintf ( 2, '%s:  ncmex::varid failed on %s, file %s.\n', mfilename, var, cdf );
	ncmex('close',cdfid);
    return
end

%
% get the number of dimensions
[var_name,var_type,nvdims,var_dim,natts, status]=ncmex('varinq',cdfid,varid);
if status < 0
	fprintf ( 2, '%s:  ncmex::varinq failed on %s, file %s.\n', mfilename, var, cdf );
	ncmex('close',cdfid);
    return
end


%
% Automagically get all the data if slab is not specified
%
for j=1:nvdims,
    dimid=var_dim(j);
    [dim_name,dim_size,rcode]=ncmex('diminq',cdfid,dimid);
	if rcode < 0
		fprintf ( 2, '%s:  ncmex::diminq failed on dimension %d, %s, file %s.\n', mfilename, j, var, cdf );
		ncmex('close',cdfid);
   	    return
	end

	varsize(j) = dim_size;
end



ncmex('close',cdfid);

status = 1;


