function status = ncattput ( ncfile, varname, attname, attval )
% NCATTPUT:  put an attribute into a netcdf file
%
% USAGE:  status = ncattput ( ncfile, varname, attname, attval );
%
% PARAMETERS:
%    status:  -1 for failure, 0 for success
%    ncfile:  name of netcdf file being altered
%    varname:  name of variable being altered.  'GLOBAL' or
%              '' denotes a global variable.
%    attname:  name of attribute being altered
%    attval:  value of attribute to be written





%
% assume failure until success is known
status = -1;

if nargin ~= 4
	fprintf ( 2, 'ncattput:  must have 4 input arguments.\n\n' );
	help ncattput;
end


%
% mexcdf is not currently capable of handling attributes other
% than double or char
switch class(attval)

	case 'double'
		att_type = 'double';

	case 'char'
		att_type = 'char';

	case 'single'
	case 'int32'
	case 'int16'
	case 'int8'
		fprintf ( 2, 'ncattput:  %s attribute type not allowd.\n\n', class(attval) );
		return;
end


%
% Suppress netcdf verbosity.
ncmex('setopts',0);

ncid=ncmex('open',ncfile,'write');
if  ncid == -1
	fprintf ( 2, 'ncattput:  ncmex failed on %s with ''write'' mode.\n\n', ncfile );
	return;
end


%
% Put into define mode.
status = ncmex ( 'redef', ncid );
if ( status == -1 )
	fprintf ( 2, ...
	          'ncattput:  ncmex operation ''redef'' failed on %s.\n\n', ...
	          ncfile );
	ncmex ( 'close', ncid );
	return;
end



status = ncmex ( 'attput', ncid, varname, ...
                 attname, att_type, length(attval), attval);
if ( status == -1 )
	fprintf ( 2, ...
	          'ncattput:  ncmex operation ''attput'' failed on %s, %s, %s attribute.\n\n', ...
	          ncfile, varname, attname );
	ncmex ( 'close', ncid );
	return;
end



%
% End define mode.
status = ncmex ( 'endef', ncid );
if ( status == -1 )
	fprintf ( 2, ...
	          'ncattput:  ncmex operation ''endef'' failed on %s.\n\n', ...
	          ncfile );
	ncmex ( 'close', ncid );
	return;
end


status = ncmex('close',ncid);
if ( status == -1 )
	fprintf ( 2, ...
	          'ncattput:  ncmex operation ''close'' failed on %s.\n\n', ...
	          ncfile );
	return;
end


%
% if we got this far, we must have succeeded.
status = 1;
return;
