function [values, status] = ncvarget(cdf, var, corner,count)
% NCVARGET Get a NetCDF hyperslab.
%  NCVARGET('CDF','VAR',[COORD],[COUNT]) returns the hyperslab 
%   from NetCDF file 'CDF, variable 'VAR', starting at corner 
%   [COORD] and containing [COUNT] elements along the edges.  
%   The starting index of an array is 0 (C-Language convention).
%
% Example:
%    [values, status] = ncvarget('foo.cdf', 'x', [0 0], [2 3])
%
% PARAMETERS:
%    values:  return data
%    status:  -1 if function failed, 0 if ok
%    CDF:  name of netcdf file
%    VAR:  name of variable to retrieve
%    COORD:  starting coordinate of the retrieval
%    COUNT:  length of the retrieval along each dimension





%
% assume failure until success is known
values = [];
status = -1;


% Show usage if too few arguments.
%
if nargin~=2 & nargin~=4,
   help nc_varget;
   return;
end

if ( nargin == 2 )
	[values, status] = nc_varget ( cdf, var );
end

if ( nargin == 4 )
	[values, status] = nc_varget ( cdf, var, corner, count );
end

return;

