function status = ncvarput(ncfile, variable, data, start,count)
% NCVARPUT: Put a NetCDF hyperslab into a NetCDF file.
%
% USAGE:  status = ncvarput(file, var, data, start, 
%                           count, dims, datatype);
%
% PARAMETERS:
%   status:  -1 for failure, 0 for success
%   
% Example:
%    status = ncvarput('foo.cdf', 'x', data, [0 0], [2 3])
%    file:  name of input netcdf file
%    var:  name of variable to write to
%    data:  to be written to netcdf file
%    start:  coordinates where we start writing to.
%            Optional.  If not supplied, assume [0,..]
%    count:  how many values to write along each dimension
%            Optional.  If not supplied, assume as much
%            as can be written.
%
% Currently, the proper error status flag is NOT set if the
% 'varput' operation fails due to improper "start" or "count"
% arguments.  If no error message is given but the data has
% obviously not be written, check that.


status = -1;


if ( nargin == 3 )
	status = nc_varput ( ncfile, variable, data );
	return;
elseif ( nargin == 5 )
	status = nc_varput ( ncfile, variable, data, start, count );
	return;
else
	help nc_varput;
end


return;


