function status = ncvarrename ( ncfile, old_variable_name, new_variable_name )
% NCVARRENAME:  Renames a NetCDF variable.
%
% USAGE:  status = ncvarrename ( netcdf_file, old_variable_name, new_variable_name );
%
% PARAMETERS:
% status:
%    -1 if process fails
% netcdf_file:  
%    Input netcdf file name.
% old_variable_name:
%    Name of variable that we wish to rename.
% new_variable_name:
%    What we want to rename it to.  Dangling participle, I know.  So sue me, Chester.







%
% assume failure until success is known
status = -1;
varnames = [];


% Show usage if too few arguments.
%
if nargin~=3 
   help ncrenamevar;
   return;
end


%
% Open netCDF file
%
[cdfid,rcode ]=ncmex('open',ncfile,'WRITE');
if cdfid < 0
	fprintf ( 2, '%s:  ncmex:open failed on %s.\n', mfilename, ncfile );
	return
end

% Suppress warning messages from netCDF
[rcode]=ncmex('setopts',0);

%
% Put into redef mode
status = ncmex('REDEF', cdfid);
if status < 0
	fprintf ( 2, '%s:  ncmex:redef failed on %s.\n', mfilename, ncfile );
	ncmex('close',cdfid);
    return
end



% 
% Find the old variable.
[varid, rcode] = ncmex('VARID', cdfid, old_variable_name);
if rcode < 0
	fprintf ( 2, '%s:  ncmex:varid failed on %s:%s.\n', mfilename, ncfile, old_variable_name );
	ncmex('close',cdfid);
    return
end


status = ncmex('VARRENAME', cdfid, varid, new_variable_name);
if status < 0
	fprintf ( 2, '%s:  ncmex:varrename failed on %s:%s.\n', mfilename, ncfile, old_variable_name );
	ncmex('close',cdfid);
    return
end

%
% Leave redef mode
status = ncmex('ENDEF', cdfid);
if status < 0
	fprintf ( 2, '%s:  ncmex:endef failed on %s.\n', mfilename, ncfile );
	ncmex('close',cdfid);
    return
end

ncmex('close',cdfid);

status = 1;

return;

